# -*- coding_utf-8 -*-
# Copyright (C) 2016-2023 PyThaiNLP Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Convert emojis
"""

import re

_emoji_th = {
    "😀": "หน้ายิ้มยิงฟัน",
    "😁": "ยิ้มยิงฟันตายิ้ม",
    "😂": "ร้องไห้ดีใจ",
    "😃": "หน้ายิ้มอ้าปาก",
    "😄": "หน้ายิ้มตายิ้ม_อ้าปาก",
    "😅": "ยิ้มเหงื่อตก",
    "😆": "ยิ้มตาหยี",
    "😇": "ยิ้มเทวดา",
    "😉": "ขยิบตา",
    "😊": "หน้ายิ้มตายิ้ม",
    "🙂": "หน้ายิ้มบางๆ",
    "🙃": "หน้ากลับหัว",
    "🤣": "ขำกลิ้ง",
    "☺": "หน้ายิ้ม",
    "😍": "ตาหัวใจ",
    "😗": "หน้าจุ๊บ",
    "😘": "หน้าส่งจุ๊บ",
    "😙": "หน้ายิ้มส่งจุ๊บ",
    "😚": "หยีตาส่งจุ๊บ",
    "🤩": "หน้าตาเป็นประกาย",
    "🥰": "หน้ายิ้มพร้อมกับหัวใจหลายดวง",
    "🥲": "ใบหน้ายิ้มทั้งน้ำตา",
    "😋": "แลบลิ้นมุมปาก",
    "😛": "แลบลิ้น",
    "😜": "แลบลิ้นหน้าทะเล้น",
    "😝": "แลบลิ้นตาหยี",
    "🤑": "หน้าเห็นแก่เงิน",
    "🤪": "หน้าเพี้ยน",
    "🤔": "หน้าครุ่นคิด",
    "🤗": "ยิ้มกอด",
    "🤫": "หน้าบอกให้เงียบ",
    "🤭": "เอามือปิดปาก",
    "😏": "แสยะยิ้ม",
    "😐": "หน้าเฉยๆ",
    "😑": "หน้าเย็นชา",
    "😒": "หน้าหน่าย",
    "😬": "เบะปาก",
    "😶": "หน้าไม่มีปาก",
    "🙄": "กลอกตา",
    "🤐": "รูดซิปปาก",
    "🤥": "ขี้โกหก",
    "🤨": "หน้าประหลาดใจกับยักคิ้ว",
    "😌": "โล่งใจ",
    "😔": "คิดไม่ตก",
    "😪": "ง่วง",
    "😴": "หลับ",
    "🤤": "น้ำลายไหล",
    "😵": "หน้ามึน",
    "😷": "ผ้าคาดปาก",
    "🤒": "อมปรอท",
    "🤕": "หัวแตก",
    "🤢": "หน้าเขียว",
    "🤧": "จาม",
    "🤮": "หน้าอาเจียน",
    "🤯": "ช็อค",
    "🥴": "หน้างงงวย",
    "🥵": "ร้อนมาก",
    "🥶": "หนาวสั่น",
    "🤠": "คาวบอยสวมหมวก",
    "🥳": "ไปปาร์ตี้",
    "🥸": "ปลอมตัว",
    "😎": "หน้ายิ้มใส่แว่น",
    "🤓": "เด็กเนิร์ด",
    "🧐": "หน้ากับแว่นเลนส์เดียว",
    "☹": "หน้าบึ้ง",
    "😓": "เหงื่อตก",
    "😕": "หน้าสับสน",
    "😖": "หน้ารำคาญ",
    "😞": "หน้าผิดหวัง",
    "😟": "หน้ากังวล",
    "😢": "ร้องไห้",
    "😣": "อดทน",
    "😥": "โล่งอก",
    "😦": "หน้าบึ้งอ้าปาก",
    "😧": "หน้าเจ็บปวด",
    "😨": "หวาดกลัว",
    "😩": "หน้าอิดโรย",
    "😫": "เหนื่อย",
    "😭": "ร้องไห้โฮ",
    "😮": "อ้าปาก",
    "😯": "หน้าจุ๊ๆ",
    "😰": "กังวลเหงื่อตก",
    "😱": "กลัวกรีดร้อง",
    "😲": "หน้าประหลาดใจ",
    "😳": "อายหน้าแดง",
    "🙁": "หน้าบึ้งเล็กน้อย",
    "🥱": "หน้ากำลังหาว",
    "🥺": "หน้าอ้อนวอน",
    "☠": "กะโหลกไขว้",
    "👿": "หน้าบึ้งมีเขา",
    "💀": "หัวกระโหลก",
    "😈": "ยิ้มมีเขา",
    "😠": "หน้าโกรธ",
    "😡": "โกรธมาก",
    "😤": "หน้าข่มอารมณ์",
    "🤬": "หน้ากำลังด่า",
    "👹": "ยักษ์ญี่ปุ่น",
    "👺": "ปีศาจญี่ปุ่น",
    "👻": "ผี",
    "👽": "เอเลี่ยน",
    "👾": "สัตว์ประหลาดเอเลี่ยน",
    "💩": "อุนจิ",
    "🤖": "หุ่นยนต์",
    "🤡": "หน้าตลก",
    "😸": "แมวยิ้มอ้าปาก_ยิ้มออกตา",
    "😹": "แมวร้องไห้ดีใจ",
    "😺": "แมวยิ้มอ้าปาก",
    "😻": "แมวยิ้มมีตารูปหัวใจ",
    "😼": "แมวยิ้มเจ้าเล่ห์",
    "😽": "แมวส่งจุ๊บ",
    "😾": "แมวโกรธ",
    "😿": "แมวร้องไห้",
    "🙀": "แมวตกใจ",
    "🙈": "ลิงปิดตา",
    "🙉": "ลิงปิดหู",
    "🙊": "ลิงปิดปาก",
    "❣": "เครื่องหมายอัศเจรีย์รูปหัวใจ",
    "❤": "หัวใจสีแดง",
    "💋": "รอยจูบ",
    "💌": "จดหมายรัก",
    "💓": "หัวใจเต้น",
    "💔": "อกหัก",
    "💕": "ใจ_2_ดวง",
    "💖": "หัวใจวิบวับ",
    "💗": "ใจพองโต",
    "💘": "ศรปักใจ",
    "💙": "หัวใจสีน้ำเงิน",
    "💚": "หัวใจสีเขียว",
    "💛": "หัวใจสีเหลือง",
    "💜": "หัวใจสีม่วง",
    "💝": "หัวใจผูกริบบิ้น",
    "💞": "หัวใจโคจร",
    "💟": "หัวใจประดับ",
    "💢": "สัญลักษณ์ความโกรธ",
    "💣": "ระเบิด",
    "💤": "หลับปุ๋ย",
    "💥": "การปะทะ",
    "💦": "เหงื่อหยด",
    "💨": "วิ่งฉิว",
    "💫": "มึนหัว",
    "💬": "พูดไม่ออก",
    "💭": "ลูกโป่งความคิด",
    "💯": "คะแนนเต็ม",
    "🕳": "หลุม",
    "🖤": "ใจดำ",
    "🗨": "ฟองคำพูด",
    "🗯": "ฟองคำพูดรุนแรง",
    "🤍": "หัวใจสีขาว",
    "🤎": "หัวใจสีน้ำตาล",
    "🧡": "หัวใจสีส้ม",
    "✋": "ตั้งฝ่ามือ",
    "👋": "โบกมือ",
    "🖐": "ชูมือกางนิ้ว",
    "🖖": "ชูนิ้วแบบวัลแคน",
    "🤚": "ยกมือ",
    "✌": "ชู_2_นิ้ว",
    "👌": "ทำมือโอเค",
    "🤌": "หุบนิ้ว",
    "🤏": "ทำมือบีบนิ้วเข้าหากัน",
    "🤘": "ชูนิ้วชาวร็อก",
    "🤙": "มือโทร",
    "🤞": "นิ้วไขว้",
    "🤟": "ทำมือ_‘ฉันรักเธอ’",
    "☝": "นิ้วชี้ขึ้น",
    "👆": "หลังมือนิ้วชี้ขึ้น",
    "👇": "นิ้วชี้ลง",
    "👈": "นิ้วชี้ทางซ้าย",
    "👉": "นิ้วชี้ทางขวา",
    "🖕": "ชูนิ้วกลาง",
    "✊": "กำมือ",
    "👊": "กำปั้น",
    "👍": "ชูนิ้วโป้งขึ้น",
    "👎": "คว่ำนิ้วโป้งลง",
    "🤛": "กำปั้นขวา",
    "🤜": "กำปั้นซ้าย",
    "👏": "ตบมือ",
    "👐": "แบมือ",
    "🙌": "ชู_2_มือ",
    "🙏": "พนมมือ",
    "🤝": "จับมือ",
    "🤲": "แบสองมือ",
    "✍": "เขียนหนังสือ",
    "💅": "สีทาเล็บ",
    "🤳": "เซลฟี่",
    "👀": "ตา_2_ข้าง",
    "👁": "ตาข้างเดียว",
    "👂": "หู",
    "👃": "จมูก",
    "👄": "ปาก",
    "👅": "ลิ้น",
    "💪": "เบ่งกล้าม",
    "🦴": "กระดูก",
    "🦵": "ขา",
    "🦶": "เท้า",
    "🦷": "ฟัน",
    "🦻": "หูใส่อุปกรณ์ช่วยฟัง",
    "🦾": "แขนกล",
    "🦿": "ขากล",
    "🧠": "สมอง",
    "🫀": "หัวใจ",
    "🫁": "ปอด",
    "👦": "เด็กชาย",
    "👧": "เด็กหญิง",
    "👨": "ผู้ชาย",
    "👩": "ผู้หญิง",
    "👱": "คนผมทอง",
    "👴": "ชายแก่",
    "👵": "หญิงแก่",
    "👶": "ทารก",
    "🧑": "คน",
    "🧒": "เด็ก",
    "🧓": "คนชรา",
    "🧔": "ผู้ชายมีเครา",
    "💁": "โต๊ะสอบถาม",
    "🙅": "มือทำท่าไม่โอเค",
    "🙆": "ทำท่าโอเค",
    "🙇": "ท่าขอโทษ",
    "🙋": "ยกมือขึ้น",
    "🙍": "ขมวดคิ้ว",
    "🙎": "ปากยื่น",
    "🤦": "หมดกัน",
    "🤷": "ยักไหล่",
    "🧏": "คนหูหนวก",
    "👮": "เจ้าหน้าที่ตำรวจ",
    "👰": "เจ้าสาว",
    "👲": "ชายจีน",
    "👳": "ชายโพกหัว",
    "👷": "คนงานก่อสร้าง",
    "👸": "เจ้าหญิง",
    "💂": "การ์ดคุ้มกัน",
    "🕵": "นักสืบ",
    "🤰": "คนท้อง",
    "🤱": "ให้นม",
    "🤴": "เจ้าชาย",
    "🤵": "คนหล่อ",
    "🥷": "นินจา",
    "🧕": "ผู้หญิงโพกศีรษะ",
    "🎅": "ซานต้า",
    "👼": "นางฟ้าเด็ก",
    "🤶": "นางซานต้า",
    "🦸": "ซุปเปอร์ฮีโร่",
    "🦹": "ยอดมนุษย์",
    "🧙": "นักเวทย์",
    "🧚": "นางฟ้า",
    "🧛": "แวมไพร์",
    "🧜": "ครึ่งคนครึ่งปลา",
    "🧝": "เอลฟ์",
    "🧞": "ยักษ์จีนี่",
    "🧟": "ซอมบี้",
    "🏃": "คนวิ่ง",
    "👯": "คนในชุดหูกระต่าย",
    "💃": "นักเต้น",
    "💆": "นวดหน้า",
    "💇": "ตัดผม",
    "🕴": "คนใส่สูทลอยได้",
    "🕺": "คนเต้น",
    "🚶": "คนเดิน",
    "🧍": "คนกำลังยืน",
    "🧎": "คนกำลังคุกเข่า",
    "🧖": "คนในห้องอบไอน้ำ",
    "🧗": "นักไต่เขา",
    "⛷": "นักสกี",
    "⛹": "คนเล่นบอล",
    "🏂": "นักสโนว์บอร์ด",
    "🏄": "นักโต้คลื่น",
    "🏇": "แข่งม้า",
    "🏊": "นักว่ายน้ำ",
    "🏋": "นักยกน้ำหนัก",
    "🏌": "นักกอล์ฟ",
    "🚣": "นักพายเรือ",
    "🚴": "นักปั่นจักรยาน",
    "🚵": "นักปั่นจักรยานเสือภูเขา",
    "🤸": "คนตีลังกา",
    "🤹": "คนเล่นจั๊กกลิ้ง",
    "🤺": "นักฟันดาบ",
    "🤼": "นักมวยปล้ำ",
    "🤽": "นักโปโลน้ำ",
    "🤾": "นักแฮนด์บอล",
    "🛀": "คนนอนแช่น้ำในอ่าง",
    "🛌": "คนนอนหลับ",
    "🧘": "คนนั่งสมาธิ",
    "👪": "ครอบครัว",
    "👫": "ชาย-หญิงจับมือ",
    "👬": "ชาย-ชายจับมือ",
    "👭": "หญิง-หญิงจับมือ",
    "💏": "จูบ",
    "💑": "คู่รัก",
    "👣": "รอยเท้า",
    "👤": "เงาครึ่งตัวคนเดียว",
    "👥": "เงาครึ่งตัว_2_คน",
    "🗣": "เงาคนกำลังพูด",
    "🫂": "คนกอดกัน",
    "🏻": "โทนผิวสีขาว",
    "🏼": "โทนผิวสีขาวเหลือง",
    "🏽": "โทนผิวสีเหลือง",
    "🏾": "โทนผิวสีแทน",
    "🏿": "โทนผิวสีเข้ม",
    "🦰": "ผมแดง",
    "🦱": "ผมหยิก",
    "🦲": "หัวล้าน",
    "🦳": "ผมขาว",
    "🐀": "หนูตัวใหญ่",
    "🐁": "หนูตัวเล็ก",
    "🐂": "วัวตัวผู้",
    "🐃": "ควาย",
    "🐄": "วัว",
    "🐅": "เสือ",
    "🐆": "เสือดาว",
    "🐇": "กระต่าย",
    "🐈": "แมว",
    "🐎": "ม้า",
    "🐏": "แกะตัวผู้",
    "🐐": "แพะ",
    "🐑": "แกะ",
    "🐒": "ลิง",
    "🐕": "สุนัข",
    "🐖": "หมู",
    "🐗": "หมูป่าตัวผู้",
    "🐘": "ช้าง",
    "🐨": "โคอาล่า",
    "🐩": "พุดเดิ้ล",
    "🐪": "อูฐโหนกเดียว",
    "🐫": "อูฐสองโหนก",
    "🐭": "หน้าหนู",
    "🐮": "หน้าวัว",
    "🐯": "หน้าเสือ",
    "🐰": "หน้ากระต่าย",
    "🐱": "หน้าแมว",
    "🐴": "หน้าม้า",
    "🐵": "หน้าลิง",
    "🐶": "หน้าสุนัข",
    "🐷": "หน้าหมู",
    "🐹": "หนูแฮมสเตอร์",
    "🐺": "หมาป่า",
    "🐻": "หมี",
    "🐼": "แพนด้า",
    "🐽": "จมูกหมู",
    "🐾": "รอยเท้าสัตว์",
    "🐿": "ชิปมังก์",
    "🦁": "สิงโต",
    "🦄": "ยูนิคอร์น",
    "🦇": "ค้างคาว",
    "🦊": "จิ้งจอก",
    "🦌": "กวาง",
    "🦍": "กอริลล่า",
    "🦏": "แรด",
    "🦒": "ยีราฟ",
    "🦓": "ม้าลาย",
    "🦔": "เฮดจ์ฮ็อก",
    "🦘": "จิงโจ้",
    "🦙": "ลามะ",
    "🦛": "ฮิปโปโปเตมัส",
    "🦝": "แรคคูน",
    "🦡": "แบดเจอร์",
    "🦣": "ช้างแมมมอธ",
    "🦥": "สลอธ",
    "🦦": "ตัวนาก",
    "🦧": "อุรังอุตัง",
    "🦨": "สกังก์",
    "🦫": "บีเวอร์",
    "🦬": "ควายไบซัน",
    "🦮": "สุนัขนำทาง",
    "🐓": "ไก่ตัวผู้",
    "🐔": "ไก่",
    "🐣": "ลูกเจี๊ยบออกจากไข่",
    "🐤": "ลูกเจี๊ยบ",
    "🐥": "ลูกเจี๊ยบยืนหันหน้า",
    "🐦": "นก",
    "🐧": "เพนกวิน",
    "🕊": "นกพิราบขาว",
    "🦃": "ไก่งวง",
    "🦅": "อินทรี",
    "🦆": "เป็ด",
    "🦉": "นกฮูก",
    "🦚": "นกยูง",
    "🦜": "นกแก้ว",
    "🦢": "หงส์",
    "🦤": "นกโดโด",
    "🦩": "นกฟลามิงโก",
    "🪶": "ขนนก",
    "🐸": "กบ",
    "🐉": "มังกร",
    "🐊": "จระเข้",
    "🐍": "งู",
    "🐢": "เต่า",
    "🐲": "หน้ามังกร",
    "🦎": "จิ้งจก",
    "🦕": "ไดโนเสาร์",
    "🦖": "ทีเร็กซ์",
    "🐋": "ปลาวาฬ",
    "🐙": "ปลาหมึกยักษ์",
    "🐚": "หอย",
    "🐟": "ปลา",
    "🐠": "ปลาเขตร้อน",
    "🐡": "ปลาปักเป้า",
    "🐬": "ปลาโลมา",
    "🐳": "ปลาวาฬพ่นน้ำ",
    "🦈": "ฉลาม",
    "🦭": "แมวน้ำ",
    "🐌": "หอยทาก",
    "🐛": "แมลง",
    "🐜": "มด",
    "🐝": "ผึ้ง",
    "🐞": "เต่าทอง",
    "🕷": "แมงมุม",
    "🕸": "ใยแมงมุม",
    "🦂": "แมงป่อง",
    "🦋": "ผีเสื้อ",
    "🦗": "จิ้งหรีด",
    "🦟": "ยุง",
    "🦠": "จุลินทรีย์",
    "🪰": "แมลงวัน",
    "🪱": "หนอน",
    "🪲": "ด้วง",
    "🪳": "แมลงสาบ",
    "🌷": "ทิวลิป",
    "🌸": "ดอกซากุระ",
    "🌹": "ดอกกุหลาบ",
    "🌺": "ดอกชบา",
    "🌻": "ดอกทานตะวัน",
    "🌼": "ดอกไม้บาน",
    "🏵": "ลายดอกกุหลาบ",
    "💐": "ช่อดอกไม้",
    "💮": "ตราดอกไม้",
    "🥀": "ดอกไม้เหี่ยว",
    "☘": "ใบโคลเวอร์",
    "🌱": "ต้นอ่อน",
    "🌲": "ต้นสน",
    "🌳": "ต้นไม้ร่มรื่น",
    "🌴": "ต้นมะพร้าว",
    "🌵": "ตะบองเพชร",
    "🌾": "รวงข้าว",
    "🌿": "สมุนไพร",
    "🍀": "ใบโคลเวอร์_4_แฉก",
    "🍁": "ใบเมเปิ้ล",
    "🍂": "ใบไม้ร่วง",
    "🍃": "ใบไม้ปลิว",
    "🪴": "ไม้กระถาง",
    "🍅": "มะเขือเทศ",
    "🍇": "องุ่น",
    "🍈": "เมลอน",
    "🍉": "แตงโม",
    "🍊": "ส้ม",
    "🍋": "เลมอน",
    "🍌": "กล้วย",
    "🍍": "สับปะรด",
    "🍎": "แอปเปิ้ลแดง",
    "🍏": "แอปเปิ้ลเขียว",
    "🍐": "ลูกแพร์",
    "🍑": "ลูกพีช",
    "🍒": "เชอร์รี่",
    "🍓": "สตรอว์เบอร์รี่",
    "🥝": "กีวี",
    "🥥": "มะพร้าว",
    "🥭": "มะม่วง",
    "🫐": "บลูเบอร์รี่",
    "🫒": "มะกอก",
    "🌰": "เกาลัด",
    "🌶": "พริก",
    "🌽": "ข้าวโพด",
    "🍄": "เห็ด",
    "🍆": "มะเขือยาว",
    "🥑": "อาโวคาโด",
    "🥒": "แตงกวา",
    "🥔": "มันฝรั่ง",
    "🥕": "แครอท",
    "🥜": "ถั่ว",
    "🥦": "บรอกโคลี",
    "🥬": "ผักใบเขียว",
    "🧄": "กระเทียม",
    "🧅": "หอมหัวใหญ่",
    "🫑": "พริกหยวก",
    "🌭": "ฮอทด็อก",
    "🌮": "ทาโก้",
    "🌯": "เบอร์ริโต",
    "🍔": "แฮมเบอร์เกอร์",
    "🍕": "พิซซ่า_1_ชิ้น",
    "🍖": "เนื้อ",
    "🍗": "น่องไก่",
    "🍞": "ขนมปัง",
    "🍟": "เฟรนช์ฟราย",
    "🍲": "สตูว์",
    "🍳": "ทำอาหาร",
    "🍿": "ป๊อปคอร์น",
    "🥐": "ครัวซอง",
    "🥓": "เบคอน",
    "🥖": "ขนมปังฝรั่งเศส",
    "🥗": "สลัด",
    "🥘": "กระทะ",
    "🥙": "เคบับ",
    "🥚": "ไข่",
    "🥞": "แพนเค้ก",
    "🥣": "ชามพร้อมช้อน",
    "🥨": "เพรตเซล",
    "🥩": "เนื้อหั่นชิ้น",
    "🥪": "แซนด์วิช",
    "🥫": "อาหารกระป๋อง",
    "🥯": "เบเกิล",
    "🧀": "เนยแข็ง",
    "🧂": "เกลือ",
    "🧆": "ฟาลาเฟล",
    "🧇": "วาฟเฟิล",
    "🧈": "เนย",
    "🫓": "แฟลตเบรด",
    "🫔": "ทามาเล่",
    "🫕": "ฟองดูว์",
    "🍘": "ข้าวอบกรอบ",
    "🍙": "ข้าวปั้น",
    "🍚": "ข้าวสวย",
    "🍛": "ข้าวแกงกะหรี่",
    "🍜": "ราเมน",
    "🍝": "สปาเก็ตตี้",
    "🍠": "มันเผา",
    "🍡": "ดังโงะ",
    "🍢": "โอเด้ง",
    "🍣": "ซูชิ",
    "🍤": "กุ้งทอด",
    "🍥": "ลูกชิ้นปลา",
    "🍱": "กล่องเบนโตะ",
    "🥟": "เกี๊ยว",
    "🥠": "คุกกี้เสี่ยงทาย",
    "🥡": "อาหารกล่องซื้อกลับบ้าน",
    "🥮": "ขนมไหว้พระจันทร์",
    "🦀": "ปู",
    "🦐": "กุ้ง",
    "🦑": "หมึก",
    "🦞": "กุ้งมังกร",
    "🦪": "หอยนางรม",
    "🍦": "ซอฟต์ครีม",
    "🍧": "น้ำแข็งไส",
    "🍨": "ไอศกรีม",
    "🍩": "โดนัท",
    "🍪": "คุกกี้",
    "🍫": "ช็อกโกแลต",
    "🍬": "ลูกอม",
    "🍭": "อมยิ้ม",
    "🍮": "คัสตาร์ด",
    "🍯": "โถน้ำผึ้ง",
    "🍰": "เค้ก",
    "🎂": "เค้กวันเกิด",
    "🥧": "พาย",
    "🧁": "คัพเค้ก",
    "☕": "เครื่องดื่มร้อน",
    "🍵": "ถ้วยชา",
    "🍶": "สาเก",
    "🍷": "ไวน์",
    "🍸": "ค็อกเทล",
    "🍹": "เครื่องดื่มผสมน้ำผลไม้",
    "🍺": "เบียร์",
    "🍻": "เหยือกเบียร์ชนกัน",
    "🍼": "ขวดนม",
    "🍾": "แชมเปญ",
    "🥂": "ชนแก้ว",
    "🥃": "แก้วเหล้า",
    "🥛": "แก้วนม",
    "🥤": "แก้วพร้อมหลอด",
    "🧃": "เครื่องดื่มแบบกล่อง",
    "🧉": "ชามาเต",
    "🧊": "ก้อนน้ำแข็ง",
    "🧋": "ชาไข่มุก",
    "🫖": "กาน้ำชา",
    "🍴": "ส้อม_มีด",
    "🍽": "จานพร้อมส้อม_มีด",
    "🏺": "โถโบราณ",
    "🔪": "มีดทำครัว",
    "🥄": "ช้อน",
    "🥢": "ตะเกียบ",
    "🌍": "ลูกโลกแสดงทวีปยุโรป_แอฟริกา",
    "🌎": "ลูกโลกแสดงทวีปอเมริกา",
    "🌏": "ลูกโลกแสดงทวีปเอเชีย_ออสเตรเลีย",
    "🌐": "ลูกโลกแสดงเส้นเมริเดียน",
    "🗺": "แผนที่โลก",
    "🗾": "แผนที่ญี่ปุ่น",
    "🧭": "เข็มทิศ",
    "⛰": "ภูเขา",
    "🌋": "ภูเขาไฟ",
    "🏔": "ภูเขามีหิมะ",
    "🏕": "ตั้งแคมป์",
    "🏖": "ร่มชายหาด",
    "🏜": "ทะเลทราย",
    "🏝": "เกาะ",
    "🏞": "อุทยาน",
    "🗻": "ภูเขาไฟฟูจิ",
    "🏗": "ก่อสร้างอาคาร",
    "🏘": "บ้านหลายหลัง",
    "🏚": "บ้านร้าง",
    "🏛": "อาคารสไตล์คลาสสิก",
    "🏟": "สนามกีฬา",
    "🏠": "บ้านเดี่ยว",
    "🏡": "บ้านพร้อมสวน",
    "🏢": "ตึกสำนักงาน",
    "🏣": "ไปรษณีย์ญี่ปุ่น",
    "🏤": "ไปรษณีย์ยุโรป",
    "🏥": "โรงพยาบาล",
    "🏦": "ธนาคาร",
    "🏨": "โรงแรม",
    "🏩": "ม่านรูด",
    "🏪": "ร้านสะดวกซื้อ",
    "🏫": "โรงเรียน",
    "🏬": "ห้างสรรพสินค้า",
    "🏭": "โรงงาน",
    "🏯": "ปราสาทญี่ปุ่น",
    "🏰": "ปราสาทยุโรป",
    "💒": "งานแต่งงาน",
    "🗼": "โตเกียวทาวเวอร์",
    "🗽": "เทพีเสรีภาพ",
    "🛖": "กระท่อม",
    "🧱": "ก้อนอิฐ",
    "🪨": "หิน",
    "🪵": "ไม้",
    "⛩": "ศาลเจ้าชินโต",
    "⛪": "โบสถ์",
    "🕋": "วิหารกะอ์บะฮ์",
    "🕌": "มัสยิด",
    "🕍": "โบสถ์ยิว",
    "🛕": "วัดฮินดู",
    "♨": "น้ำพุร้อน",
    "⛲": "น้ำพุ",
    "⛺": "เต็นท์",
    "🌁": "หมอกลง",
    "🌃": "ดาว",
    "🌄": "ดวงอาทิตย์โผล่พ้นเขา",
    "🌅": "ดวงอาทิตย์ขึ้น",
    "🌆": "เมืองยามโพล้เพล้",
    "🌇": "ดวงอาทิตย์ตก",
    "🌉": "สะพานกลางคืน",
    "🎠": "ม้าหมุน",
    "🎡": "ชิงช้าสวรรค์",
    "🎢": "รถไฟเหาะ",
    "🎪": "ละครสัตว์",
    "🏙": "หมู่ตึกสูง",
    "💈": "ร้านตัดผม",
    "⛽": "ปั๊มน้ำมัน",
    "🏍": "มอเตอร์ไซค์",
    "🏎": "รถแข่ง",
    "🚂": "หัวรถจักรไอน้ำ",
    "🚃": "ตู้รถไฟ",
    "🚄": "ชินคันเซ็น",
    "🚅": "รถไฟความเร็วสูง",
    "🚆": "รถไฟ",
    "🚇": "รถไฟใต้ดิน",
    "🚈": "รถไฟรางเบา",
    "🚉": "สถานีรถไฟ",
    "🚊": "รถรางบนราง",
    "🚋": "ตู้รถราง",
    "🚌": "รถบัส",
    "🚍": "รถบัสกำลังมา",
    "🚎": "รถราง",
    "🚏": "ป้ายรถบัส",
    "🚐": "มินิบัส",
    "🚑": "รถพยาบาล",
    "🚒": "รถดับเพลิง",
    "🚓": "รถตำรวจ",
    "🚔": "รถตำรวจกำลังมา",
    "🚕": "แท็กซี่",
    "🚖": "แท็กซี่กำลังมา",
    "🚗": "รถ",
    "🚘": "รถกำลังมา",
    "🚙": "รถบ้าน",
    "🚚": "รถขนส่ง",
    "🚛": "รถบรรทุก",
    "🚜": "แทร็กเตอร์",
    "🚝": "รถไฟรางเดี่ยว",
    "🚞": "รางรถไฟภูเขา",
    "🚥": "ไฟจราจรแนวนอน",
    "🚦": "ไฟจราจรแนวตั้ง",
    "🚧": "ป้ายไซต์ก่อสร้าง",
    "🚨": "สัญญาณไฟตำรวจ",
    "🚲": "จักรยาน",
    "🛑": "เครื่องหมายหยุด",
    "🛢": "ถังน้ำมัน",
    "🛣": "ทางด่วน",
    "🛤": "รางรถไฟ",
    "🛴": "สกู๊ตเตอร์",
    "🛵": "รถสกู๊ตเตอร์",
    "🛹": "สเก็ตบอร์ด",
    "🛺": "รถสามล้อ",
    "🛻": "รถกระบะ",
    "🛼": "รองเท้าสเก็ต",
    "🦼": "วีลแชร์ไฟฟ้า",
    "🦽": "วีลแชร์ธรรมดา",
    "⚓": "สมอเรือ",
    "⛴": "เรือเฟอร์รี",
    "⛵": "เรือใบ",
    "🚢": "เรือ",
    "🚤": "เรือด่วน",
    "🛥": "เรือยนต์",
    "🛳": "เรือโดยสาร",
    "🛶": "แคนู",
    "✈": "เครื่องบิน",
    "💺": "ที่นั่ง",
    "🚀": "จรวด",
    "🚁": "เฮลิคอปเตอร์",
    "🚟": "รถไฟสะพานแขวน",
    "🚠": "เคเบิลคาร์",
    "🚡": "รถกระเช้าลอยฟ้า",
    "🛩": "เครื่องบินเล็ก",
    "🛫": "เครื่องบินขึ้น",
    "🛬": "เครื่องบินลง",
    "🛰": "ดาวเทียม",
    "🛸": "จานบิน",
    "🪂": "ร่มชูชีพ",
    "🛎": "กระดิ่งโรงแรม",
    "🧳": "กระเป๋าเดินทาง",
    "⌚": "นาฬิกาข้อมือ",
    "⌛": "นาฬิกาทราย",
    "⏰": "นาฬิกาปลุก",
    "⏱": "นาฬิกาจับเวลา",
    "⏲": "นาฬิกานับถอยหลัง",
    "⏳": "นาฬิกาทรายจับเวลา",
    "🕐": "หนึ่งนาฬิกา",
    "🕑": "สองนาฬิกา",
    "🕒": "สามนาฬิกา",
    "🕓": "สี่นาฬิกา",
    "🕔": "ห้านาฬิกา",
    "🕕": "หกนาฬิกา",
    "🕖": "เจ็ดนาฬิกา",
    "🕗": "แปดนาฬิกา",
    "🕘": "เก้านาฬิกา",
    "🕙": "สิบนาฬิกา",
    "🕚": "สิบเอ็ดนาฬิกา",
    "🕛": "สิบสองนาฬิกา",
    "🕜": "หนึ่งนาฬิกาครึ่ง",
    "🕝": "สองนาฬิกาครึ่ง",
    "🕞": "สามนาฬิกาครึ่ง",
    "🕟": "สี่นาฬิกาครึ่ง",
    "🕠": "ห้านาฬิกาครึ่ง",
    "🕡": "หกนาฬิกาครึ่ง",
    "🕢": "เจ็ดนาฬิกาครึ่ง",
    "🕣": "แปดนาฬิกาครึ่ง",
    "🕤": "เก้านาฬิกาครึ่ง",
    "🕥": "สิบนาฬิกาครึ่ง",
    "🕦": "สิบเอ็ดนาฬิกาครึ่ง",
    "🕧": "สิบสองนาฬิกาครึ่ง",
    "🕰": "นาฬิกาบนหิ้ง",
    "☀": "พระอาทิตย์",
    "☁": "เมฆ",
    "☂": "ร่ม",
    "☃": "สโนว์แมน_หิมะ",
    "☄": "ดาวหาง",
    "☔": "ร่ม_หยดน้ำฝน",
    "⚡": "ไฟฟ้าแรงสูง",
    "⛄": "สโนว์แมน",
    "⛅": "ดวงอาทิตย์หลังเมฆ",
    "⛈": "ฝนฟ้าคะนอง",
    "⛱": "ร่มปักดิน",
    "❄": "เกล็ดหิมะ",
    "⭐": "ดาวสีขาวขนาดกลาง",
    "🌀": "ไซโคลน",
    "🌂": "ร่มหุบ",
    "🌈": "รุ้ง",
    "🌊": "คลื่น",
    "🌌": "ทางช้างเผือก",
    "🌑": "จันทร์ดับ",
    "🌒": "พระจันทร์เสี้ยวข้างขึ้น",
    "🌓": "พระจันทร์ครึ่งซีกขวา",
    "🌔": "ข้างขึ้น",
    "🌕": "พระจันทร์เต็มดวง",
    "🌖": "ข้างแรม",
    "🌗": "พระจันทร์ครึ่งซีกซ้าย",
    "🌘": "พระจันทร์เสี้ยวข้างแรม",
    "🌙": "พระจันทร์เสี้ยว",
    "🌚": "หน้าพระจันทร์ดับ",
    "🌛": "หน้าพระจันทร์เสี้ยวขวา",
    "🌜": "หน้าพระจันทร์เสี้ยวซ้าย",
    "🌝": "หน้าพระจันทร์เต็มดวง",
    "🌞": "หน้าพระอาทิตย์",
    "🌟": "ดาวส่องแสง",
    "🌠": "ดาวตก",
    "🌡": "เครื่องวัดอุณหภูมิ",
    "🌤": "เมฆน้อยบดบังพระอาทิตย์",
    "🌥": "เมฆก้อนใหญ่บังพระอาทิตย์",
    "🌦": "เมฆฝนบดบังพระอาทิตย์",
    "🌧": "เมฆฝน",
    "🌨": "เมฆ_หิมะ",
    "🌩": "เมฆ_ฟ้าแลบ",
    "🌪": "พายุทอร์นาโด",
    "🌫": "หมอก",
    "🌬": "พ่นลม",
    "💧": "หยดน้ำ",
    "🔥": "ไฟ",
    "🪐": "ดาวเคราะห์ที่มีวงแหวน",
    "✨": "ประกายวิบวับ",
    "🎀": "ริบบิ้น",
    "🎁": "ของขวัญ",
    "🎃": "ฟักทองฮาโลวีน",
    "🎄": "ต้นคริสต์มาส",
    "🎆": "พลุ",
    "🎇": "ดอกไม้ไฟ",
    "🎈": "ลูกโป่ง",
    "🎉": "ปาร์ตี้",
    "🎊": "ลูกบอลใส่เศษกระดาษงานปาร์ตี้",
    "🎋": "ต้นไม้ประดับคำอวยพร",
    "🎍": "ต้นสนประดับ",
    "🎎": "ตุ๊กตาญี่ปุ่น",
    "🎏": "ธงปลาคาร์พ",
    "🎐": "โมบายล์กระดิ่ง",
    "🎑": "ไหว้พระจันทร์",
    "🎗": "ริบบิ้นรำลึก",
    "🎟": "ตั๋วเข้าชม",
    "🎫": "ตั๋ว",
    "🧧": "อั่งเปา",
    "🧨": "ประทัด",
    "🎖": "เหรียญกล้าหาญ",
    "🏅": "เหรียญรางวัล",
    "🏆": "ถ้วยรางวัล",
    "🥇": "เหรียญทอง",
    "🥈": "เหรียญเงิน",
    "🥉": "เหรียญทองแดง",
    "⚽": "ลูกฟุตบอล",
    "⚾": "เบสบอล",
    "⛳": "ธงในหลุม",
    "⛸": "สเก็ตน้ำแข็ง",
    "🎣": "ตกปลา",
    "🎳": "โบว์ลิ่ง",
    "🎽": "เสื้อวิ่ง",
    "🎾": "เทนนิส",
    "🎿": "สกี",
    "🏀": "บาสเกตบอล",
    "🏈": "อเมริกันฟุตบอล",
    "🏉": "รักบี้",
    "🏏": "คริกเก็ต",
    "🏐": "วอลเลย์บอล",
    "🏑": "ฮอกกี้",
    "🏒": "ไม้ฮอกกี้",
    "🏓": "ปิงปอง",
    "🏸": "แบดมินตัน",
    "🛷": "เลื่อนหิมะ",
    "🤿": "หน้ากากดำน้ำ",
    "🥅": "โกล",
    "🥊": "นวม",
    "🥋": "ชุดยูโด",
    "🥌": "ลูกกลิ้งหิน",
    "🥍": "ลาครอส",
    "🥎": "ซอฟต์บอล",
    "🥏": "จานร่อน",
    "♟": "หมากรุก",
    "♠": "โพดำ",
    "♣": "ดอกจิก",
    "♥": "โพแดง",
    "♦": "ข้าวหลามตัด",
    "🀄": "ไพ่นกกระจอกมังกรแดง",
    "🃏": "ไพ่โจ๊กเกอร์",
    "🎮": "วิดีโอเกม",
    "🎯": "กลางเป้า",
    "🎰": "สล็อตแมชชีน",
    "🎱": "บิลเลียด",
    "🎲": "ลูกเต๋า",
    "🎴": "ไพ่ดอกไม้",
    "🔮": "ลูกแก้ววิเศษ",
    "🕹": "จอยสติ๊ก",
    "🧩": "จิ๊กซอว์",
    "🧸": "ตุ๊กตาหมี",
    "🧿": "เครื่องราง",
    "🪀": "โยโย่",
    "🪁": "ว่าว",
    "🪄": "ไม้กายสิทธิ์",
    "🪅": "ปิญญาตา",
    "🪆": "ตุ๊กตาแม่ลูกดก",
    "🎨": "จานสีวาดรูป",
    "🎭": "หน้ากาก",
    "🖼": "รูปใส่กรอบ",
    "🧵": "ด้าย",
    "🧶": "ไหมพรม",
    "🪡": "เข็มเย็บผ้า",
    "🪢": "เงื่อน",
    "⛑": "หมวกนิรภัยมีกากบาทขาว",
    "🎒": "เป้นักเรียน",
    "🎓": "หมวกรับปริญญา",
    "🎩": "หมวกสูง",
    "👑": "มงกุฎ",
    "👒": "หมวกผู้หญิง",
    "👓": "แว่นตา",
    "👔": "เนคไท",
    "👕": "เสื้อยืด",
    "👖": "ยีนส์",
    "👗": "ชุดกระโปรง",
    "👘": "กิโมโน",
    "👙": "บิกินี",
    "👚": "เสื้อผู้หญิง",
    "👛": "กระเป๋าใส่เงิน",
    "👜": "กระเป๋าถือ",
    "👝": "กระเป๋าใบเล็ก",
    "👞": "รองเท้าชาย",
    "👟": "รองเท้ากีฬา",
    "👠": "รองเท้าส้นสูง",
    "👡": "รองเท้าแตะผู้หญิง",
    "👢": "รองเท้าบู๊ตผู้หญิง",
    "💄": "ลิปสติก",
    "💍": "แหวน",
    "💎": "อัญมณี",
    "📿": "ลูกประคำ",
    "🕶": "แว่นกันแดด",
    "🛍": "ถุงช็อปปิ้ง",
    "🥻": "ชุดส่าหรี",
    "🥼": "เสื้อกาวน์",
    "🥽": "แว่นตากันลม",
    "🥾": "รองเท้าปีนเขา",
    "🥿": "รองเท้าส้นเตี้ย",
    "🦺": "เสื้อนิรภัย",
    "🧢": "หมวกแก๊ป",
    "🧣": "ผ้าพันคอ",
    "🧤": "ถุงมือ",
    "🧥": "เสื้อโค้ต",
    "🧦": "ถุงเท้า",
    "🩰": "รองเท้าบัลเล่ต์",
    "🩱": "ชุดว่ายน้ำวันพีซ",
    "🩲": "กางเกงชั้นในชาย",
    "🩳": "กางเกงขาสั้น",
    "🩴": "รองเท้าลำลอง",
    "🪖": "หมวกทหาร",
    "📢": "เครื่องขยายเสียง",
    "📣": "โทรโข่ง",
    "📯": "แตรส่งสาร",
    "🔇": "ไม่ใช้เสียง",
    "🔈": "ลำโพงเสียงเบา",
    "🔉": "ลำโพงเสียงปานกลาง",
    "🔊": "ลำโพงเสียงดัง",
    "🔔": "กระดิ่ง",
    "🔕": "ไม่มีกระดิ่ง",
    "🎙": "ไมค์สตูดิโอ",
    "🎚": "ที่ปรับระดับเสียง",
    "🎛": "ปุ่มควบคุมเสียง",
    "🎤": "ไมโครโฟน",
    "🎧": "หูฟัง",
    "🎵": "โน้ตดนตรี",
    "🎶": "โน้ตดนตรีหลายตัว",
    "🎼": "บรรทัดห้าเส้น",
    "📻": "วิทยุ",
    "🎷": "แซ็กโซโฟน",
    "🎸": "กีต้าร์",
    "🎹": "เปียโน",
    "🎺": "ทรัมเป็ต",
    "🎻": "ไวโอลิน",
    "🥁": "กลอง",
    "🪕": "แบนโจ",
    "🪗": "แอคคอร์เดียน",
    "🪘": "กลองยาว",
    "☎": "โทรศัพท์",
    "📞": "หูโทรศัพท์",
    "📟": "เพจเจอร์",
    "📠": "แฟกซ์",
    "📱": "โทรศัพท์มือถือ",
    "📲": "โทรศัพท์มือถือพร้อมลูกศรชี้",
    "⌨": "แป้นพิมพ์",
    "💻": "แล็ปท็อป",
    "💽": "แผ่นดิสก์",
    "💾": "ฟลอปปี้ดิสก์",
    "💿": "บลูเรย์",
    "📀": "ดีวีดี",
    "🔋": "แบตเตอรี่",
    "🔌": "ปลั๊กไฟ",
    "🖥": "คอมพิวเตอร์เดสก์ท็อป",
    "🖨": "เครื่องพิมพ์",
    "🖱": "เมาส์",
    "🖲": "แทร็กบอล",
    "🧮": "ลูกคิด",
    "🎞": "เฟรมภาพยนตร์",
    "🎥": "กล้องถ่ายภาพยนตร์",
    "🎬": "สเลท",
    "🏮": "โคมไฟแดง",
    "💡": "หลอดไฟ",
    "📷": "กล้อง",
    "📸": "กล้องเปิดแฟลช",
    "📹": "กล้องวิดีโอ",
    "📺": "ทีวี",
    "📼": "วิดีโอเทป",
    "📽": "เครื่องฉายหนัง",
    "🔍": "แว่นขยายเอียงซ้าย",
    "🔎": "แว่นขยายเอียงขวา",
    "🔦": "ไฟฉาย",
    "🕯": "เทียน",
    "🪔": "ตะเกียงดิยา",
    "🏷": "ป้าย",
    "📃": "เอกสารม้วนปลาย",
    "📄": "เอกสาร",
    "📑": "แถบคั่นหน้า",
    "📒": "สมุดโน้ตเจาะรูข้าง",
    "📓": "สมุดโน้ต",
    "📔": "สมุดโน้ตมีลาย",
    "📕": "หนังสือปิด",
    "📖": "หนังสือเปิด",
    "📗": "หนังสือสีเขียว",
    "📘": "หนังสือสีน้ำเงิน",
    "📙": "หนังสือสีส้ม",
    "📚": "หนังสือ",
    "📜": "ม้วนกระดาษ",
    "📰": "หนังสือพิมพ์",
    "🔖": "ที่คั่นหนังสือ",
    "🗞": "ม้วนหนังสือพิมพ์",
    "💰": "ถุงเงิน",
    "💳": "บัตรเครดิต",
    "💴": "ธนบัตรเยน",
    "💵": "ธนบัตรดอลลาร์",
    "💶": "ธนบัตรยูโร",
    "💷": "ธนบัตรปอนด์",
    "💸": "เงินบิน",
    "💹": "ตลาดขึ้น",
    "🧾": "ใบเสร็จ",
    "🪙": "เหรียญ",
    "✉": "ซองจดหมาย",
    "📤": "กล่องขาออก",
    "📥": "กล่องขาเข้า",
    "📦": "พัสดุ",
    "📧": "อีเมล",
    "📨": "จดหมายเข้า",
    "📩": "จดหมายออก",
    "📪": "กล่องจดหมายปิดคว่ำธง",
    "📫": "กล่องจดหมายปิดยกธง",
    "📬": "กล่องจดหมายมีจดหมาย",
    "📭": "กล่องจดหมายว่าง",
    "📮": "ตู้ไปรษณีย์",
    "🗳": "หีบบัตรลงคะแนน",
    "✏": "ดินสอ",
    "✒": "ปลายปากกาสีดำ",
    "📝": "จดบันทึก",
    "🖊": "ปากกา",
    "🖋": "ปากกาหมึกซึม",
    "🖌": "แปรงทาสี",
    "🖍": "ดินสอสี",
    "✂": "กรรไกร",
    "💼": "กระเป๋าเอกสาร",
    "📁": "แฟ้มเอกสาร",
    "📂": "เปิดเอกสาร",
    "📅": "ปฏิทิน",
    "📆": "ปฏิทินแบบฉีกออก",
    "📇": "ที่ใส่บัตร",
    "📈": "แนวโน้มขึ้น",
    "📉": "แนวโน้มลง",
    "📊": "กราฟแท่ง",
    "📋": "คลิปบอร์ด",
    "📌": "หมุดปัก",
    "📍": "หมุดหัวกลม",
    "📎": "คลิปหนีบกระดาษ",
    "📏": "ไม้บรรทัดตรง",
    "📐": "ไม้บรรทัดสามเหลี่ยม",
    "🖇": "คลิปหนีบกระดาษคู่",
    "🗂": "ที่คั่นบัตรรายการ",
    "🗃": "กล่องใส่แฟ้ม",
    "🗄": "ตู้เอกสาร",
    "🗑": "ตะกร้าขยะ",
    "🗒": "สมุดโน้ตสันห่วง",
    "🗓": "ปฏิทินสันห่วง",
    "🔏": "ล็อคด้วยปากกา",
    "🔐": "ล็อคด้วยกุญแจ",
    "🔑": "กุญแจ",
    "🔒": "ล็อคปิด",
    "🔓": "ล็อคเปิด",
    "🗝": "กุญแจเก่า",
    "⚒": "ค้อน_จอบ",
    "⚔": "ดาบไขว้",
    "⚖": "ตราชั่ง",
    "⚙": "เฟือง",
    "⛏": "จอบ",
    "⛓": "โซ่",
    "🏹": "ธนู_ลูกศร",
    "🔗": "สัญลักษณ์การลิงก์",
    "🔧": "ประแจ",
    "🔨": "ค้อน",
    "🔩": "สลัก_น็อต",
    "🔫": "ปืนฉีดน้ำ",
    "🗜": "เครื่องบีบอัด",
    "🗡": "ดาบสั้น",
    "🛠": "ค้อน_ประแจ",
    "🛡": "โล่",
    "🦯": "ไม้เท้านำทาง",
    "🧰": "กล่องเครื่องมือ",
    "🧲": "แม่เหล็ก",
    "🪃": "บูมเมอแรง",
    "🪓": "ขวาน",
    "🪚": "เลื่อย",
    "🪛": "ไขควง",
    "🪜": "บันไดปีน",
    "🪝": "ตะขอ",
    "⚗": "อุปกรณ์กลั่น",
    "📡": "จานดาวเทียม",
    "🔬": "กล้องจุลทรรศน์",
    "🔭": "กล้องโทรทรรศน์",
    "🧪": "หลอดทดลอง",
    "🧫": "จานเพาะเชื้อ",
    "🧬": "ดีเอ็นเอ",
    "💉": "กระบอกฉีดยา",
    "💊": "ยาเม็ด",
    "🩸": "หยดเลือด",
    "🩹": "พลาสเตอร์ปิดแผล",
    "🩺": "เครื่องฟังตรวจ",
    "🚪": "ประตู",
    "🚽": "โถส้วม",
    "🚿": "ฝักบัว",
    "🛁": "อ่างอาบน้ำ",
    "🛋": "โซฟากับโคมไฟ",
    "🛏": "เตียง",
    "🛒": "รถเข็น",
    "🛗": "ลิฟต์",
    "🧯": "ที่ดับเพลิง",
    "🧴": "ขวดโลชั่น",
    "🧷": "เข็มกลัดซ่อนปลาย",
    "🧹": "ไม้กวาด",
    "🧺": "ตะกร้า",
    "🧻": "กระดาษชำระ",
    "🧼": "สบู่",
    "🧽": "ฟองน้ำ",
    "🪑": "เก้าอี้",
    "🪒": "ใบมีดโกน",
    "🪞": "กระจก",
    "🪟": "หน้าต่าง",
    "🪠": "ที่ปั๊มชักโครก",
    "🪣": "ถัง",
    "🪤": "กับดักหนู",
    "🪥": "แปรงสีฟัน",
    "⚰": "โลงศพ",
    "⚱": "โกศกระดูก",
    "🗿": "รูปปั้นโมไอ",
    "🚬": "ป้ายสูบบุหรี่",
    "🪦": "แผ่นหินจารึก",
    "🪧": "ป้ายประกาศ",
    "♿": "รถเข็นผู้ป่วย",
    "🏧": "เอทีเอ็ม",
    "🚮": "ทิ้งขยะให้ลงถัง",
    "🚰": "น้ำดื่ม",
    "🚹": "ห้องน้ำชาย",
    "🚺": "ห้องน้ำหญิง",
    "🚻": "ห้องน้ำ",
    "🚼": "ป้ายทารก",
    "🚾": "ป้ายห้องน้ำ",
    "🛂": "ตรวจพาสปอร์ต",
    "🛃": "ศุลกากร",
    "🛄": "รับสัมภาระ",
    "🛅": "บริการฝากกระเป๋า",
    "☢": "กัมมันตรังสี",
    "☣": "เชื้อโรคอันตราย",
    "⚠": "ป้ายระวัง",
    "⛔": "ป้ายห้ามเข้า",
    "📵": "ห้ามใช้โทรศัพท์",
    "🔞": "ห้ามอายุต่ำกว่า_18_ปี",
    "🚫": "ป้ายหวงห้าม",
    "🚭": "ป้ายห้ามสูบบุหรี่",
    "🚯": "ห้ามทิ้งขยะ",
    "🚱": "ห้ามดื่มน้ำ",
    "🚳": "ห้ามจักรยาน",
    "🚷": "ห้ามคนเดินเท้า",
    "🚸": "เด็กๆ_ข้ามถนน",
    "↔": "ลูกศรชี้ซ้ายขวา",
    "↕": "ลูกศรชี้ขึ้นลง",
    "↖": "ลูกศรชี้มุมซ้ายบน",
    "↗": "ลูกศรชี้มุมขวาบน",
    "↘": "ลูกศรชี้มุมขวาล่าง",
    "↙": "ลูกศรชี้มุุมซ้ายล่าง",
    "↩": "ลูกศรวนซ้าย",
    "↪": "ลูกศรวนขวา",
    "➡": "ลูกศรชี้ไปทางขวา",
    "⤴": "ลูกศรโค้งขึ้น",
    "⤵": "ลูกศรโค้งลง",
    "⬅": "ลูกศรชี้ไปทางซ้าย",
    "⬆": "ลูกศรชี้ขึ้น",
    "⬇": "ลูกศรชี้ลง",
    "🔃": "สัญลักษณ์โหลดซ้ำ",
    "🔄": "ลูกศรทวนเข็มนาฬิกา",
    "🔙": "กลับ",
    "🔚": "สิ้นสุด",
    "🔛": "เปิด",
    "🔜": "สัญลักษณ์เร็วๆ_นี้",
    "🔝": "สัญลักษณ์บน",
    "☦": "ไม้กางเขนออร์โธดอกซ์",
    "☪": "พระจันทร์เสี้ยว_ดาว",
    "☮": "เครื่องหมายสันติภาพ",
    "☯": "หยินหยาง",
    "☸": "ธรรมจักร",
    "⚛": "อะตอม",
    "✝": "ไม้กางเขนละติน",
    "✡": "สตาร์ออฟเดวิด",
    "🔯": "ดาว_6_แฉก",
    "🕉": "เครื่องหมายโอม",
    "🕎": "เชิงเทียน_7_กิ่ง",
    "🛐": "ที่บูชา",
    "♈": "ราศีเมษ",
    "♉": "ราศีพฤษภ",
    "♊": "ราศีเมถุน",
    "♋": "ราศีกรกฎ",
    "♌": "ราศีสิงห์",
    "♍": "ราศีกันย์",
    "♎": "ราศีตุลย์",
    "♏": "ราศีพิจิก",
    "♐": "ราศีธนู",
    "♑": "ราศีมังกร",
    "♒": "ราศีกุมภ์",
    "♓": "ราศีมีน",
    "⛎": "กลุ่มดาวคนแบกงู",
    "⏏": "ปุ่มดีดออก",
    "⏩": "เร่งไปข้างหน้า",
    "⏪": "ถอยกลับ",
    "⏫": "ลูกศรขึ้น",
    "⏬": "ลูกศรลง",
    "⏭": "เล่นแทร็กถัดไป",
    "⏮": "ปุ่มแทร็กก่อนหน้า",
    "⏯": "เล่นหรือหยุดชั่วคราว",
    "⏸": "ปุ่มหยุุดชั่วคราว",
    "⏹": "ปุ่มหยุด",
    "⏺": "ปุ่มอัด",
    "▶": "เล่น",
    "◀": "ย้อนกลับ",
    "🎦": "โรงภาพยนตร์",
    "📳": "โหมดสั่น",
    "📴": "ปิดมือถือ",
    "📶": "สัญญาณมือถือ",
    "🔀": "ลูกศรไขว้",
    "🔁": "เล่นซ้ำ",
    "🔂": "เล่นซ้ำเพลงเดียว",
    "🔅": "แสงสว่างน้อย",
    "🔆": "แสงสว่างมาก",
    "🔼": "ปุ่มสามเหลี่ยมขึ้น",
    "🔽": "ปุ่มสามเหลี่ยมลง",
    "♀": "สัญลักษณ์เพศหญิง",
    "♂": "สัญลักษณ์เพศชาย",
    "⚧": "สัญลักษณ์คนข้ามเพศ",
    "©": "ลิขสิทธิ์",
    "®": "จดทะเบียน",
    "‼": "เครื่องหมายอัศเจรีย์คู่",
    "⁉": "เครื่องหมายอัศเจรีย์_คำถาม",
    "™": "เครื่องหมายการค้า",
    "☑": "กล่องกาเครื่องหมายมีเครื่องหมายถูก",
    "♻": "สัญลักษณ์รีไซเคิล",
    "♾": "ไม่มีที่สิ้นสุด",
    "⚕": "เครื่องหมายการแพทย์",
    "⚜": "สัญลักษณ์ดอกลิลลี่",
    "✅": "ปุ่มเครื่องหมายถูก",
    "✔": "เครื่องหมายถูก",
    "✖": "คูณ",
    "✳": "ดอกจัน_8_ซี่",
    "✴": "ดาว_8_แฉก",
    "❇": "เปล่งประกาย",
    "❌": "เครื่องหมายกากบาท",
    "❎": "ปุ่มเครื่องหมายกากบาท",
    "❓": "เครื่องหมายคำถาม",
    "❔": "เครื่องหมายคำถามสีขาว",
    "❕": "เครื่องหมายอัศเจรีย์สีขาว",
    "❗": "เครื่องหมายอัศเจรีย์สีแดง",
    "➕": "บวก",
    "➖": "ลบ",
    "➗": "หาร",
    "➰": "ห่วง",
    "➿": "ห่วง_2_รู",
    "⭕": "วงกลมกลวงสีแดง",
    "〰": "เส้นคลื่น",
    "〽": "เครื่องหมายเปลี่ยนท่อน",
    "💱": "การแลกเปลี่ยนเงิน",
    "💲": "สัญลักษณ์ดอลลาร์",
    "📛": "ป้ายชื่อ",
    "🔰": "สัญลักษณ์มือใหม่หัดขับ",
    "🔱": "ฉมวก",
    "🔟": "ปุ่มกดเลข_10",
    "ℹ": "แหล่งข้อมูล",
    "Ⓜ": "ตัวเอ็มในวงกลม",
    "㊗": "ภาษาญี่ปุ่นคำว่า_“แสดงความยินดี”",
    "㊙": "ภาษาญี่ปุ่นคำว่า_“ความลับ”",
    "🅰": "เลือดกรุ๊ปเอ",
    "🅱": "เลือดกรุ๊ปบี",
    "🅾": "เลือดกรุ๊ปโอ",
    "🅿": "ที่จอดรถ",
    "🆎": "เลือดกรุ๊ปเอบี",
    "🆑": "ลบข้อมูล",
    "🆒": "เย็น",
    "🆓": "ฟรี",
    "🆔": "หมายเลขประจำตัว",
    "🆕": "ใหม่",
    "🆖": "ปุ่มเอ็นจี",
    "🆗": "โอเค",
    "🆘": "ช่วยด้วย",
    "🆙": "ขึ้น",
    "🆚": "ต่อสู้กับ",
    "🈁": "ภาษาญี่ปุ่นคำว่า_“ที่นี่”",
    "🈂": "ภาษาญี่ปุ่นคำว่า_“ค่าบริการ”",
    "🈚": "ภาษาญี่ปุ่นคำว่า_“ไม่มี”",
    "🈯": "ภาษาญี่ปุ่นคำว่า_“จองแล้ว”",
    "🈲": "ภาษาญี่ปุ่นคำว่า_“ห้าม”",
    "🈳": "ภาษาจีนว่างเปล่า",
    "🈴": "ภาษาญี่ปุ่นคำว่า_“ผ่าน”",
    "🈵": "ภาษาญี่ปุ่นคำว่า_“เต็ม”",
    "🈶": "ภาษาญี่ปุ่นคำว่า_“คิดค่าใช้จ่าย”",
    "🈷": "ภาษาญี่ปุ่นคำว่า_“จำนวนต่อเดือน”",
    "🈸": "ภาษาญี่ปุ่นคำว่า_“ใบสมัคร”",
    "🈹": "ภาษาญี่ปุ่นคำว่า_“ส่วนลด”",
    "🈺": "ภาษาญี่ปุ่นคำว่า_“เปิดทำการ”",
    "🉐": "ภาษาญี่ปุ่นคำว่า_“ราคาถูก”",
    "🉑": "ภาษาญี่ปุ่นคำว่า_“ยอมรับได้”",
    "🔠": "อักษรตัวพิมพ์ใหญ่",
    "🔡": "อักษรตัวพิมพ์เล็ก",
    "🔢": "หมายเลข",
    "🔣": "สัญลักษณ์",
    "🔤": "ตัวอักษรภาษาอังกฤษ",
    "▪": "สี่เหลี่ยมเล็กสีดำ",
    "▫": "สี่เหลี่ยมเล็กสีขาว",
    "◻": "สี่เหลี่ยมขนาดกลางสีขาว",
    "◼": "สี่เหลี่ยมขนาดกลางสีดำ",
    "◽": "สี่เหลี่ยมเล็กปานกลางสีขาว",
    "◾": "สี่เหลี่ยมเล็กปานกลางสีดำ",
    "⚪": "วงกลมสีขาว",
    "⚫": "วงกลมสีดำ",
    "⬛": "สี่เหลี่ยมใหญ่สีดำ",
    "⬜": "สี่เหลี่ยมใหญ่สีขาว",
    "💠": "ข้าวหลามตัดมีจุดตรงกลาง",
    "🔘": "ปุ่มวิทยุ",
    "🔲": "ปุ่มสี่เหลี่ยมขอบดำ",
    "🔳": "ปุ่มสี่เหลี่ยมขอบขาว",
    "🔴": "วงกลมสีแดง",
    "🔵": "วงกลมสีน้ำเงิน",
    "🔶": "เพชรใหญ่สีส้ม",
    "🔷": "เพชรใหญ่สีน้ำเงิน",
    "🔸": "เพชรเล็กสีส้ม",
    "🔹": "เพชรเล็กสีน้ำเงิน",
    "🔺": "สามเหลี่ยมหงายสีแดง",
    "🔻": "สามเหลี่ยมคว่ำสีแดง",
    "🟠": "วงกลมสีส้ม",
    "🟡": "วงกลมสีเหลือง",
    "🟢": "วงกลมสีเขียว",
    "🟣": "วงกลมสีม่วง",
    "🟤": "วงกลมสีน้ำตาล",
    "🟥": "สี่เหลี่ยมสีแดง",
    "🟦": "สี่เหลี่ยมสีน้ำเงิน",
    "🟧": "สี่เหลี่ยมสีส้ม",
    "🟨": "สี่เหลี่ยมสีเหลือง",
    "🟩": "สี่เหลี่ยมสีเขียว",
    "🟪": "สี่เหลี่ยมสีม่วง",
    "🟫": "สี่เหลี่ยมสีน้ำตาล",
    "🎌": "ธงไขว้",
    "🏁": "ธงตราหมากรุก",
    "🏳": "ธงขาว",
    "🏴": "ธงดำ",
    "🚩": "ธงปักตำแหน่ง",
    "#⃣": "ปุ่มกดเลข_#",
    "*⃣": "ปุ่มกดเลข_*",
    "0⃣": "ปุ่มกดเลข_0",
    "1⃣": "ปุ่มกดเลข_1",
    "2⃣": "ปุ่มกดเลข_2",
    "3⃣": "ปุ่มกดเลข_3",
    "4⃣": "ปุ่มกดเลข_4",
    "5⃣": "ปุ่มกดเลข_5",
    "6⃣": "ปุ่มกดเลข_6",
    "7⃣": "ปุ่มกดเลข_7",
    "8⃣": "ปุ่มกดเลข_8",
    "9⃣": "ปุ่มกดเลข_9",
    "🇦🇨": "ธง_เกาะแอสเซนชัน",
    "🇦🇩": "ธง_อันดอร์รา",
    "🇦🇪": "ธง_สหรัฐอาหรับเอมิเรตส์",
    "🇦🇫": "ธง_อัฟกานิสถาน",
    "🇦🇬": "ธง_แอนติกา_บาร์บูดา",
    "🇦🇮": "ธง_แองกวิลลา",
    "🇦🇱": "ธง_แอลเบเนีย",
    "🇦🇲": "ธง_อาร์เมเนีย",
    "🇦🇴": "ธง_แองโกลา",
    "🇦🇶": "ธง_แอนตาร์กติกา",
    "🇦🇷": "ธง_อาร์เจนตินา",
    "🇦🇸": "ธง_อเมริกันซามัว",
    "🇦🇹": "ธง_ออสเตรีย",
    "🇦🇺": "ธง_ออสเตรเลีย",
    "🇦🇼": "ธง_อารูบา",
    "🇦🇽": "ธง_หมู่เกาะโอลันด์",
    "🇦🇿": "ธง_อาเซอร์ไบจาน",
    "🇧🇦": "ธง_บอสเนีย_เฮอร์เซโกวีนา",
    "🇧🇧": "ธง_บาร์เบโดส",
    "🇧🇩": "ธง_บังกลาเทศ",
    "🇧🇪": "ธง_เบลเยียม",
    "🇧🇫": "ธง_บูร์กินาฟาโซ",
    "🇧🇬": "ธง_บัลแกเรีย",
    "🇧🇭": "ธง_บาห์เรน",
    "🇧🇮": "ธง_บุรุนดี",
    "🇧🇯": "ธง_เบนิน",
    "🇧🇱": "ธง_เซนต์บาร์เธเลมี",
    "🇧🇲": "ธง_เบอร์มิวดา",
    "🇧🇳": "ธง_บรูไน",
    "🇧🇴": "ธง_โบลิเวีย",
    "🇧🇶": "ธง_เนเธอร์แลนด์แคริบเบียน",
    "🇧🇷": "ธง_บราซิล",
    "🇧🇸": "ธง_บาฮามาส",
    "🇧🇹": "ธง_ภูฏาน",
    "🇧🇻": "ธง_เกาะบูเว",
    "🇧🇼": "ธง_บอตสวานา",
    "🇧🇾": "ธง_เบลารุส",
    "🇧🇿": "ธง_เบลีซ",
    "🇨🇦": "ธง_แคนาดา",
    "🇨🇨": "ธง_หมู่เกาะโคโคส_(คีลิง)",
    "🇨🇩": "ธง_คองโก_-_กินชาซา",
    "🇨🇫": "ธง_สาธารณรัฐแอฟริกากลาง",
    "🇨🇬": "ธง_คองโก_-_บราซซาวิล",
    "🇨🇭": "ธง_สวิตเซอร์แลนด์",
    "🇨🇮": "ธง_โกตดิวัวร์",
    "🇨🇰": "ธง_หมู่เกาะคุก",
    "🇨🇱": "ธง_ชิลี",
    "🇨🇲": "ธง_แคเมอรูน",
    "🇨🇳": "ธง_จีน",
    "🇨🇴": "ธง_โคลอมเบีย",
    "🇨🇵": "ธง_เกาะคลิปเปอร์ตัน",
    "🇨🇷": "ธง_คอสตาริกา",
    "🇨🇺": "ธง_คิวบา",
    "🇨🇻": "ธง_เคปเวิร์ด",
    "🇨🇼": "ธง_คูราเซา",
    "🇨🇽": "ธง_เกาะคริสต์มาส",
    "🇨🇾": "ธง_ไซปรัส",
    "🇨🇿": "ธง_เช็ก",
    "🇩🇪": "ธง_เยอรมนี",
    "🇩🇬": "ธง_ดิเอโกการ์เซีย",
    "🇩🇯": "ธง_จิบูตี",
    "🇩🇰": "ธง_เดนมาร์ก",
    "🇩🇲": "ธง_โดมินิกา",
    "🇩🇴": "ธง_สาธารณรัฐโดมินิกัน",
    "🇩🇿": "ธง_แอลจีเรีย",
    "🇪🇦": "ธง_เซวตา_เมลียา",
    "🇪🇨": "ธง_เอกวาดอร์",
    "🇪🇪": "ธง_เอสโตเนีย",
    "🇪🇬": "ธง_อียิปต์",
    "🇪🇭": "ธง_ซาฮาราตะวันตก",
    "🇪🇷": "ธง_เอริเทรีย",
    "🇪🇸": "ธง_สเปน",
    "🇪🇹": "ธง_เอธิโอเปีย",
    "🇪🇺": "ธง_สหภาพยุโรป",
    "🇫🇮": "ธง_ฟินแลนด์",
    "🇫🇯": "ธง_ฟิจิ",
    "🇫🇰": "ธง_หมู่เกาะฟอล์กแลนด์",
    "🇫🇲": "ธง_ไมโครนีเซีย",
    "🇫🇴": "ธง_หมู่เกาะแฟโร",
    "🇫🇷": "ธง_ฝรั่งเศส",
    "🇬🇦": "ธง_กาบอง",
    "🇬🇧": "ธง_สหราชอาณาจักร",
    "🇬🇩": "ธง_เกรเนดา",
    "🇬🇪": "ธง_จอร์เจีย",
    "🇬🇫": "ธง_เฟรนช์เกียนา",
    "🇬🇬": "ธง_เกิร์นซีย์",
    "🇬🇭": "ธง_กานา",
    "🇬🇮": "ธง_ยิบรอลตาร์",
    "🇬🇱": "ธง_กรีนแลนด์",
    "🇬🇲": "ธง_แกมเบีย",
    "🇬🇳": "ธง_กินี",
    "🇬🇵": "ธง_กวาเดอลูป",
    "🇬🇶": "ธง_อิเควทอเรียลกินี",
    "🇬🇷": "ธง_กรีซ",
    "🇬🇸": "ธง_เกาะเซาท์จอร์เจีย_หมู่เกาะเซาท์แซนด์วิช",
    "🇬🇹": "ธง_กัวเตมาลา",
    "🇬🇺": "ธง_กวม",
    "🇬🇼": "ธง_กินี-บิสเซา",
    "🇬🇾": "ธง_กายอานา",
    "🇭🇰": "ธง_เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน",
    "🇭🇲": "ธง_เกาะเฮิร์ด_หมู่เกาะแมกดอนัลด์",
    "🇭🇳": "ธง_ฮอนดูรัส",
    "🇭🇷": "ธง_โครเอเชีย",
    "🇭🇹": "ธง_เฮติ",
    "🇭🇺": "ธง_ฮังการี",
    "🇮🇨": "ธง_หมู่เกาะคานารี",
    "🇮🇩": "ธง_อินโดนีเซีย",
    "🇮🇪": "ธง_ไอร์แลนด์",
    "🇮🇱": "ธง_อิสราเอล",
    "🇮🇲": "ธง_เกาะแมน",
    "🇮🇳": "ธง_อินเดีย",
    "🇮🇴": "ธง_บริติชอินเดียนโอเชียนเทร์ริทอรี",
    "🇮🇶": "ธง_อิรัก",
    "🇮🇷": "ธง_อิหร่าน",
    "🇮🇸": "ธง_ไอซ์แลนด์",
    "🇮🇹": "ธง_อิตาลี",
    "🇯🇪": "ธง_เจอร์ซีย์",
    "🇯🇲": "ธง_จาเมกา",
    "🇯🇴": "ธง_จอร์แดน",
    "🇯🇵": "ธง_ญี่ปุ่น",
    "🇰🇪": "ธง_เคนยา",
    "🇰🇬": "ธง_คีร์กีซสถาน",
    "🇰🇭": "ธง_กัมพูชา",
    "🇰🇮": "ธง_คิริบาส",
    "🇰🇲": "ธง_คอโมโรส",
    "🇰🇳": "ธง_เซนต์คิตส์_เนวิส",
    "🇰🇵": "ธง_เกาหลีเหนือ",
    "🇰🇷": "ธง_เกาหลีใต้",
    "🇰🇼": "ธง_คูเวต",
    "🇰🇾": "ธง_หมู่เกาะเคย์แมน",
    "🇰🇿": "ธง_คาซัคสถาน",
    "🇱🇦": "ธง_ลาว",
    "🇱🇧": "ธง_เลบานอน",
    "🇱🇨": "ธง_เซนต์ลูเซีย",
    "🇱🇮": "ธง_ลิกเตนสไตน์",
    "🇱🇰": "ธง_ศรีลังกา",
    "🇱🇷": "ธง_ไลบีเรีย",
    "🇱🇸": "ธง_เลโซโท",
    "🇱🇹": "ธง_ลิทัวเนีย",
    "🇱🇺": "ธง_ลักเซมเบิร์ก",
    "🇱🇻": "ธง_ลัตเวีย",
    "🇱🇾": "ธง_ลิเบีย",
    "🇲🇦": "ธง_โมร็อกโก",
    "🇲🇨": "ธง_โมนาโก",
    "🇲🇩": "ธง_มอลโดวา",
    "🇲🇪": "ธง_มอนเตเนโกร",
    "🇲🇫": "ธง_เซนต์มาร์ติน",
    "🇲🇬": "ธง_มาดากัสการ์",
    "🇲🇭": "ธง_หมู่เกาะมาร์แชลล์",
    "🇲🇰": "ธง_มาซิโดเนียเหนือ",
    "🇲🇱": "ธง_มาลี",
    "🇲🇲": "ธง_เมียนมา_(พม่า)",
    "🇲🇳": "ธง_มองโกเลีย",
    "🇲🇴": "ธง_เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน",
    "🇲🇵": "ธง_หมู่เกาะนอร์เทิร์นมาเรียนา",
    "🇲🇶": "ธง_มาร์ตินีก",
    "🇲🇷": "ธง_มอริเตเนีย",
    "🇲🇸": "ธง_มอนต์เซอร์รัต",
    "🇲🇹": "ธง_มอลตา",
    "🇲🇺": "ธง_มอริเชียส",
    "🇲🇻": "ธง_มัลดีฟส์",
    "🇲🇼": "ธง_มาลาวี",
    "🇲🇽": "ธง_เม็กซิโก",
    "🇲🇾": "ธง_มาเลเซีย",
    "🇲🇿": "ธง_โมซัมบิก",
    "🇳🇦": "ธง_นามิเบีย",
    "🇳🇨": "ธง_นิวแคลิโดเนีย",
    "🇳🇪": "ธง_ไนเจอร์",
    "🇳🇫": "ธง_เกาะนอร์ฟอล์ก",
    "🇳🇬": "ธง_ไนจีเรีย",
    "🇳🇮": "ธง_นิการากัว",
    "🇳🇱": "ธง_เนเธอร์แลนด์",
    "🇳🇴": "ธง_นอร์เวย์",
    "🇳🇵": "ธง_เนปาล",
    "🇳🇷": "ธง_นาอูรู",
    "🇳🇺": "ธง_นีอูเอ",
    "🇳🇿": "ธง_นิวซีแลนด์",
    "🇴🇲": "ธง_โอมาน",
    "🇵🇦": "ธง_ปานามา",
    "🇵🇪": "ธง_เปรู",
    "🇵🇫": "ธง_เฟรนช์โปลินีเซีย",
    "🇵🇬": "ธง_ปาปัวนิวกินี",
    "🇵🇭": "ธง_ฟิลิปปินส์",
    "🇵🇰": "ธง_ปากีสถาน",
    "🇵🇱": "ธง_โปแลนด์",
    "🇵🇲": "ธง_แซงปีแยร์_มีเกอลง",
    "🇵🇳": "ธง_หมู่เกาะพิตแคร์น",
    "🇵🇷": "ธง_เปอร์โตริโก",
    "🇵🇸": "ธง_ดินแดนปาเลสไตน์",
    "🇵🇹": "ธง_โปรตุเกส",
    "🇵🇼": "ธง_ปาเลา",
    "🇵🇾": "ธง_ปารากวัย",
    "🇶🇦": "ธง_กาตาร์",
    "🇷🇪": "ธง_เรอูนียง",
    "🇷🇴": "ธง_โรมาเนีย",
    "🇷🇸": "ธง_เซอร์เบีย",
    "🇷🇺": "ธง_รัสเซีย",
    "🇷🇼": "ธง_รวันดา",
    "🇸🇦": "ธง_ซาอุดีอาระเบีย",
    "🇸🇧": "ธง_หมู่เกาะโซโลมอน",
    "🇸🇨": "ธง_เซเชลส์",
    "🇸🇩": "ธง_ซูดาน",
    "🇸🇪": "ธง_สวีเดน",
    "🇸🇬": "ธง_สิงคโปร์",
    "🇸🇭": "ธง_เซนต์เฮเลนา",
    "🇸🇮": "ธง_สโลวีเนีย",
    "🇸🇯": "ธง_สฟาลบาร์_ยานไมเอน",
    "🇸🇰": "ธง_สโลวะเกีย",
    "🇸🇱": "ธง_เซียร์ราลีโอน",
    "🇸🇲": "ธง_ซานมาริโน",
    "🇸🇳": "ธง_เซเนกัล",
    "🇸🇴": "ธง_โซมาเลีย",
    "🇸🇷": "ธง_ซูรินาเม",
    "🇸🇸": "ธง_ซูดานใต้",
    "🇸🇹": "ธง_เซาตูเม_ปรินซิปี",
    "🇸🇻": "ธง_เอลซัลวาดอร์",
    "🇸🇽": "ธง_ซินต์มาร์เทน",
    "🇸🇾": "ธง_ซีเรีย",
    "🇸🇿": "ธง_เอสวาตีนี",
    "🇹🇦": "ธง_ทริสตันดาคูนา",
    "🇹🇨": "ธง_หมู่เกาะเติกส์_หมู่เกาะเคคอส",
    "🇹🇩": "ธง_ชาด",
    "🇹🇫": "ธง_เฟรนช์เซาเทิร์นเทร์ริทอรีส์",
    "🇹🇬": "ธง_โตโก",
    "🇹🇭": "ธง_ไทย",
    "🇹🇯": "ธง_ทาจิกิสถาน",
    "🇹🇰": "ธง_โตเกเลา",
    "🇹🇱": "ธง_ติมอร์-เลสเต",
    "🇹🇲": "ธง_เติร์กเมนิสถาน",
    "🇹🇳": "ธง_ตูนิเซีย",
    "🇹🇴": "ธง_ตองกา",
    "🇹🇷": "ธง_ตุรกี",
    "🇹🇹": "ธง_ตรินิแดด_โตเบโก",
    "🇹🇻": "ธง_ตูวาลู",
    "🇹🇼": "ธง_ไต้หวัน",
    "🇹🇿": "ธง_แทนซาเนีย",
    "🇺🇦": "ธง_ยูเครน",
    "🇺🇬": "ธง_ยูกันดา",
    "🇺🇲": "ธง_หมู่เกาะรอบนอกของสหรัฐอเมริกา",
    "🇺🇳": "ธง_สหประชาชาติ",
    "🇺🇸": "ธง_สหรัฐอเมริกา",
    "🇺🇾": "ธง_อุรุกวัย",
    "🇺🇿": "ธง_อุซเบกิสถาน",
    "🇻🇦": "ธง_นครวาติกัน",
    "🇻🇨": "ธง_เซนต์วินเซนต์_เกรนาดีนส์",
    "🇻🇪": "ธง_เวเนซุเอลา",
    "🇻🇬": "ธง_หมู่เกาะบริติชเวอร์จิน",
    "🇻🇮": "ธง_หมู่เกาะเวอร์จินของสหรัฐอเมริกา",
    "🇻🇳": "ธง_เวียดนาม",
    "🇻🇺": "ธง_วานูอาตู",
    "🇼🇫": "ธง_วาลลิส_ฟุตูนา",
    "🇼🇸": "ธง_ซามัว",
    "🇽🇰": "ธง_โคโซโว",
    "🇾🇪": "ธง_เยเมน",
    "🇾🇹": "ธง_มายอต",
    "🇿🇦": "ธง_แอฟริกาใต้",
    "🇿🇲": "ธง_แซมเบีย",
    "🇿🇼": "ธง_ซิมบับเว",
    "👁‍🗨": "ตาในลูกโป่งคำพูด",
    "👨‍🦰": "ผู้ชาย_ผมแดง",
    "👨‍🦱": "ผู้ชาย_ผมหยิก",
    "👨‍🦲": "ผู้ชาย_หัวล้าน",
    "👨‍🦳": "ผู้ชาย_ผมขาว",
    "👩‍🦰": "ผู้หญิง_ผมแดง",
    "👩‍🦱": "ผู้หญิง_ผมหยิก",
    "👩‍🦲": "ผู้หญิง_หัวล้าน",
    "👩‍🦳": "ผู้หญิง_ผมขาว",
    "👱‍♀": "ผู้หญิงผมทอง",
    "👱‍♂": "ผู้ชายผมทอง",
    "🧑‍🦰": "คน_ผมแดง",
    "🧑‍🦱": "คน_ผมหยิก",
    "🧑‍🦲": "คน_หัวล้าน",
    "🧑‍🦳": "คน_ผมขาว",
    "💁‍♀": "ผู้หญิงแบมือ",
    "💁‍♂": "ผู้ชายแบมือ",
    "🙅‍♀": "ผู้หญิงทำท่าไม่โอเค",
    "🙅‍♂": "ผู้ชายทำท่าไม่โอเค",
    "🙆‍♀": "ผู้หญิงทำท่าโอเค",
    "🙆‍♂": "ผู้ชายทำท่าโอเค",
    "🙇‍♀": "ผู้หญิงหมอบคำนับ",
    "🙇‍♂": "ผู้ชายหมอบคำนับ",
    "🙋‍♀": "ผู้หญิงยกมือ",
    "🙋‍♂": "ผู้ชายยกมือ",
    "🙍‍♀": "ผู้หญิงหน้าบึ้ง",
    "🙍‍♂": "ผู้ชายหน้าบึ้ง",
    "🙎‍♀": "ผู้หญิงโกรธ",
    "🙎‍♂": "ผู้ชายโกรธ",
    "🤦‍♀": "ผู้หญิงเอามือก่ายหน้าผาก",
    "🤦‍♂": "ผู้ชายเอามือก่ายหน้าผาก",
    "🤷‍♀": "ผู้หญิงยักไหล่",
    "🤷‍♂": "ผู้ชายยักไหล่",
    "🧏‍♀": "ผู้หญิงหูหนวก",
    "🧏‍♂": "ผู้ชายหูหนวก",
    "👨‍⚕": "หมอชาย",
    "👨‍⚖": "ผู้พิพากษาชาย",
    "👨‍✈": "นักบินชาย",
    "👨‍🌾": "ชาวนาชาย",
    "👨‍🍳": "พ่อครัว",
    "👨‍🍼": "ผู้ชายให้นมลูก",
    "👨‍🎓": "นักเรียนชาย",
    "👨‍🎤": "นักร้องชาย",
    "👨‍🎨": "ศิลปินชาย",
    "👨‍🏫": "ครูชาย",
    "👨‍🏭": "พนักงานโรงงานชาย",
    "👨‍💻": "ผู้เชี่ยวชาญด้านเทคโนโลยีชาย",
    "👨‍💼": "พนักงานบริษัทชาย",
    "👨‍🔧": "ช่างซ่อมชาย",
    "👨‍🔬": "นักวิทยาศาสตร์ชาย",
    "👨‍🚀": "นักบินอวกาศชาย",
    "👨‍🚒": "พนักงานดับเพลิงชาย",
    "👩‍⚕": "หมอหญิง",
    "👩‍⚖": "ผู้พิพากษาหญิง",
    "👩‍✈": "นักบินหญิง",
    "👩‍🌾": "ชาวนาหญิง",
    "👩‍🍳": "แม่ครัว",
    "👩‍🍼": "ผู้หญิงให้นมลูก",
    "👩‍🎓": "นักเรียนหญิง",
    "👩‍🎤": "นักร้องหญิง",
    "👩‍🎨": "ศิลปินหญิง",
    "👩‍🏫": "ครูหญิง",
    "👩‍🏭": "พนักงานโรงงานหญิง",
    "👩‍💻": "ผู้เชี่ยวชาญด้านเทคโนโลยีหญิง",
    "👩‍💼": "พนักงานบริษัทหญิง",
    "👩‍🔧": "ช่างซ่อมหญิง",
    "👩‍🔬": "นักวิทยาศาสตร์หญิง",
    "👩‍🚀": "นักบินอวกาศหญิง",
    "👩‍🚒": "พนักงานดับเพลิงหญิง",
    "👮‍♀": "ตำรวจหญิง",
    "👮‍♂": "ตำรวจชาย",
    "👰‍♀": "ผู้หญิงที่มีผ้าคลุมหน้า",
    "👰‍♂": "ผู้ชายที่มีผ้าคลุมหน้า",
    "👳‍♀": "ผู้หญิงโพกหัว",
    "👳‍♂": "ผู้ชายโพกหัว",
    "👷‍♀": "พนักงานก่อสร้างหญิง",
    "👷‍♂": "พนักงานก่อสร้างชาย",
    "💂‍♀": "องครักษ์หญิง",
    "💂‍♂": "องครักษ์ชาย",
    "🕵‍♀": "นักสืบหญิง",
    "🕵‍♂": "นักสืบชาย",
    "🤵‍♀": "ผู้หญิงใส่ทักซิโด้",
    "🤵‍♂": "ผู้ชายใส่ทักซิโด้",
    "🧑‍⚕": "หมอ",
    "🧑‍⚖": "ผู้พิพากษา",
    "🧑‍✈": "นักบิน",
    "🧑‍🌾": "ชาวนา",
    "🧑‍🍳": "กุ๊ก",
    "🧑‍🍼": "คนให้นมลูก",
    "🧑‍🎓": "บัณฑิต",
    "🧑‍🎤": "นักร้อง",
    "🧑‍🎨": "ศิลปิน",
    "🧑‍🏫": "ครู",
    "🧑‍🏭": "พนักงานโรงงาน",
    "🧑‍💻": "ผู้เชี่ยวชาญด้านเทคโนโลยี",
    "🧑‍💼": "พนักงานออฟฟิศ",
    "🧑‍🔧": "ช่างกล",
    "🧑‍🔬": "นักวิทยาศาสตร์",
    "🧑‍🚀": "นักบินอวกาศ",
    "🧑‍🚒": "พนักงานดับเพลิง",
    "🦸‍♀": "ยอดหญิง",
    "🦸‍♂": "พระเอก",
    "🦹‍♀": "นางร้าย",
    "🦹‍♂": "ตัวโกง",
    "🧑‍🎄": "ซานตาคลอส",
    "🧙‍♀": "แม่มด",
    "🧙‍♂": "พ่อมด",
    "🧚‍♀": "เทพธิดา",
    "🧚‍♂": "เทพบุตร",
    "🧛‍♀": "แวมไพร์ผู้หญิง",
    "🧛‍♂": "แวมไพร์ผู้ชาย",
    "🧜‍♀": "เงือก",
    "🧜‍♂": "เงือกชาย",
    "🧝‍♀": "เอลฟ์ผู้หญิง",
    "🧝‍♂": "เอลฟ์ผู้ชาย",
    "🧞‍♀": "ยักษ์จีนี่หญิง",
    "🧞‍♂": "ยักษ์จีนี่ชาย",
    "🧟‍♀": "ซอมบี้ผู้หญิง",
    "🧟‍♂": "ซอมบี้ผู้ชาย",
    "🏃‍♀": "ผู้หญิงวิ่ง",
    "🏃‍♂": "ผู้ชายวิ่ง",
    "👨‍🦯": "ผู้ชายเดินถือไม้เท้านำทาง",
    "👨‍🦼": "ผู้ชายนั่งวีลแชร์ไฟฟ้า",
    "👨‍🦽": "ผู้ชายนั่งวีลแชร์ธรรมดา",
    "👩‍🦯": "ผู้หญิงเดินถือไม้เท้านำทาง",
    "👩‍🦼": "ผู้หญิงนั่งวีลแชร์ไฟฟ้า",
    "👩‍🦽": "ผู้หญิงนั่งวีลแชร์ธรรมดา",
    "👯‍♀": "ผู้หญิงในชุดหูกระต่าย",
    "👯‍♂": "ผู้ชายในชุดหูกระต่าย",
    "💆‍♀": "ผู้หญิงกำลังนวดหน้า",
    "💆‍♂": "ผู้ชายกำลังนวดหน้า",
    "💇‍♀": "ผู้หญิงกำลังตัดผม",
    "💇‍♂": "ผู้ชายกำลังตัดผม",
    "🚶‍♀": "ผู้หญิงเดิน",
    "🚶‍♂": "ผู้ชายเดิน",
    "🧍‍♀": "ผู้หญิงกำลังยืน",
    "🧍‍♂": "ผู้ชายกำลังยืน",
    "🧎‍♀": "ผู้หญิงกำลังคุกเข่า",
    "🧎‍♂": "ผู้ชายกำลังคุกเข่า",
    "🧑‍🦯": "คนเดินถือไม้เท้านำทาง",
    "🧑‍🦼": "คนนั่งวีลแชร์ไฟฟ้า",
    "🧑‍🦽": "คนนั่งวีลแชร์ธรรมดา",
    "🧖‍♀": "ผู้หญิงในห้องอบไอน้ำ",
    "🧖‍♂": "ผู้ชายในห้องอบไอน้ำ",
    "🧗‍♀": "ผู้หญิงไต่เขา",
    "🧗‍♂": "ผู้ชายไต่เขา",
    "⛹‍♀": "ผู้หญิงเล่นบอล",
    "⛹‍♂": "ผู้ชายเล่นบอล",
    "🏄‍♀": "ผู้หญิงโต้คลื่น",
    "🏄‍♂": "ผู้ชายโต้คลื่น",
    "🏊‍♀": "ผู้หญิงว่ายน้ำ",
    "🏊‍♂": "ผู้ชายว่ายน้ำ",
    "🏋‍♀": "ผู้หญิงยกน้ำหนัก",
    "🏋‍♂": "ผู้ชายยกน้ำหนัก",
    "🏌‍♀": "ผู้หญิงตีกอล์ฟ",
    "🏌‍♂": "ผู้ชายตีกอล์ฟ",
    "🚣‍♀": "ผู้หญิงพายเรือ",
    "🚣‍♂": "ผู้ชายพายเรือ",
    "🚴‍♀": "ผู้หญิงปั่นจักรยาน",
    "🚴‍♂": "ผู้ชายปั่นจักรยาน",
    "🚵‍♀": "ผู้หญิงปั่นจักรยานเสือภูเขา",
    "🚵‍♂": "ผู้ชายปั่นจักรยานเสือภูเขา",
    "🤸‍♀": "ผู้หญิงตีลังกา",
    "🤸‍♂": "ผู้ชายตีลังกา",
    "🤹‍♀": "ผู้หญิงเล่นจั๊กกลิ้ง",
    "🤹‍♂": "ผู้ชายเล่นจั๊กกลิ้ง",
    "🤼‍♀": "ผู้หญิงเล่นมวยปล้ำ",
    "🤼‍♂": "ผู้ชายเล่นมวยปล้ำ",
    "🤽‍♀": "ผู้หญิงเล่นโปโลน้ำ",
    "🤽‍♂": "ผู้ชายเล่นโปโลน้ำ",
    "🤾‍♀": "ผู้หญิงเล่นแฮนด์บอล",
    "🤾‍♂": "ผู้ชายเล่นแฮนด์บอล",
    "🧘‍♀": "ผู้หญิงนั่งสมาธิ",
    "🧘‍♂": "ผู้ชายนั่งสมาธิ",
    "👨‍👦": "ครอบครัว_ผู้ชาย_เด็กชาย",
    "👨‍👧": "ครอบครัว_ผู้ชาย_เด็กหญิง",
    "👩‍👦": "ครอบครัว_ผู้หญิง_เด็กชาย",
    "👩‍👧": "ครอบครัว_ผู้หญิง_เด็กหญิง",
    "🐈‍⬛": "แมวดำ",
    "🐕‍🦺": "สุนัขบริการ",
    "🐻‍❄": "หมีขั้วโลก",
    "🏳‍⚧": "ธงคนข้ามเพศ",
    "🏳‍🌈": "ธงสีรุ้ง",
    "🏴‍☠": "ธงโจรสลัด",
    "👨‍❤‍👨": "คู่รัก_ผู้ชาย_ผู้ชาย",
    "👨‍👦‍👦": "ครอบครัว_ผู้ชาย_เด็กชาย_เด็กชาย",
    "👨‍👧‍👦": "ครอบครัว_ผู้ชาย_เด็กหญิง_เด็กชาย",
    "👨‍👧‍👧": "ครอบครัว_ผู้ชาย_เด็กหญิง_เด็กหญิง",
    "👨‍👨‍👦": "ครอบครัว_ผู้ชาย_ผู้ชาย_เด็กชาย",
    "👨‍👨‍👧": "ครอบครัว_ผู้ชาย_ผู้ชาย_เด็กหญิง",
    "👨‍👩‍👦": "ครอบครัว_ผู้ชาย_ผู้หญิง_เด็กชาย",
    "👨‍👩‍👧": "ครอบครัว_ผู้ชาย_ผู้หญิง_เด็กหญิง",
    "👩‍❤‍👨": "คู่รัก_ผู้หญิง_ผู้ชาย",
    "👩‍❤‍👩": "คู่รัก_ผู้หญิง_ผู้หญิง",
    "👩‍👦‍👦": "ครอบครัว_ผู้หญิง_เด็กชาย_เด็กชาย",
    "👩‍👧‍👦": "ครอบครัว_ผู้หญิง_เด็กหญิง_เด็กชาย",
    "👩‍👧‍👧": "ครอบครัว_ผู้หญิง_เด็กหญิง_เด็กหญิง",
    "👩‍👩‍👦": "ครอบครัว_ผู้หญิง_ผู้หญิง_เด็กชาย",
    "👩‍👩‍👧": "ครอบครัว_ผู้หญิง_ผู้หญิง_เด็กหญิง",
    "🧑‍🤝‍🧑": "คนจับมือกัน",
    "👨‍❤‍💋‍👨": "จูบ_ผู้ชาย_ผู้ชาย",
    "👨‍👨‍👦‍👦": "ครอบครัว_ผู้ชาย_ผู้ชาย_เด็กชาย_เด็กชาย",
    "👨‍👨‍👧‍👦": "ครอบครัว_ผู้ชาย_ผู้ชาย_เด็กหญิง_เด็กชาย",
    "👨‍👨‍👧‍👧": "ครอบครัว_ผู้ชาย_ผู้ชาย_เด็กหญิง_เด็กหญิง",
    "👨‍👩‍👦‍👦": "ครอบครัว_ผู้ชาย_ผู้หญิง_เด็กชาย_เด็กชาย",
    "👨‍👩‍👧‍👦": "ครอบครัว_ผู้ชาย_ผู้หญิง_เด็กหญิง_เด็กชาย",
    "👨‍👩‍👧‍👧": "ครอบครัว_ผู้ชาย_ผู้หญิง_เด็กหญิง_เด็กหญิง",
    "👩‍❤‍💋‍👨": "จูบ_ผู้หญิง_ผู้ชาย",
    "👩‍❤‍💋‍👩": "จูบ_ผู้หญิง_ผู้หญิง",
    "👩‍👩‍👦‍👦": "ครอบครัว_ผู้หญิง_ผู้หญิง_เด็กชาย_เด็กชาย",
    "👩‍👩‍👧‍👦": "ครอบครัว_ผู้หญิง_ผู้หญิง_เด็กหญิง_เด็กชาย",
    "👩‍👩‍👧‍👧": "ครอบครัว_ผู้หญิง_ผู้หญิง_เด็กหญิง_เด็กหญิง",
    "🏴󠁧󠁢󠁥󠁮󠁧󠁿": "ธง_อังกฤษ",
    "🏴󠁧󠁢󠁳󠁣󠁴󠁿": "ธง_สกอตแลนด์",
    "🏴󠁧󠁢󠁷󠁬󠁳󠁿": "ธง_เวลส์",
}

_th_emoji = {v: k for k, v in _emoji_th.items()}

_emojis = sorted(_emoji_th.keys(), key=len, reverse=True)
_emoji_regex = re.compile("|".join(map(re.escape, _emojis)))
_delimiter = ":"


def emoji_to_thai(text: str, delimiters=(_delimiter, _delimiter)) -> str:
    """
    This function convert emoji to thai meaning

    :param str text: Text with Emoji
    :return: Text with Emoji being converted to thai meaning
    :rtype: str

    :Example:
    ::

        from pythainlp.util import emoji_to_thai

        emoji_to_thai("จะมานั่งรถเมล์เหมือนผมก็ได้นะครับ ใกล้ชิดประชาชนดี 😀")
        # output: จะมานั่งรถเมล์เหมือนผมก็ได้นะครับ
                  ใกล้ชิดประชาชนดี :หน้ายิ้มยิงฟัน:

        emoji_to_thai("หิวข้าวอยากกินอาหารญี่ปุ่น 🍣")
        # output: หิวข้าวอยากกินอาหารญี่ปุ่น :ซูชิ:

        emoji_to_thai("🇹🇭 นี่คือธงประเทศไทย")
        # output: :ธง_ไทย: นี่คือธงประเทศไทย
    """

    return _emoji_regex.sub(
        lambda match: delimiters[0]
        + _emoji_th[match.group(0)]
        + delimiters[1],
        text,
    )
